#include "mbed.h"
#include "espterm.h"

DigitalOut led(LED1);
ESPTerm term(PA_9, PA_10); // UART not used by the Nucleo ACM

void onchar(char c);
void onmouse(int row, int col, MouseEvent evt);

int main()
{   
    // Wait for ESP ready (send "Device Status Query" and wait for "Device OK")
    term.clear_status();
    while (term.query_status() == false) {
        wait_ms(100);        
        led = !led;    
    }
    
    // Connect handlers
    term.on_char_rx = onchar; 
    term.on_mouse = onmouse;
    
    // others: (check the declarations in the .h file)
    // term.on_esp_reset - on esp reset, we should re-init the screen etc
    // term.on_key - user pushed an arrow key
    // term.on_button - user pushed a button under the screen
    
    term.set_screen_size(25, 60);

    int i = 0;
    while(1) {
        wait_ms(1000);        
        led = !led; // heartbeat       
        term.println("> %d", i++);
    }
}

// --- handlers ---

// User typed a character that's not part of a control sequence
void onchar(char c)
{
    // change it to indicate we did something
    term.putc(c+1);   
}

// User clicked (events other than 0 are not implemented as of v0.5.5)
void onmouse(int row, int col, MouseEvent event)
{
    term.fg(GREEN);
    term.println("Mouse evt %d @ %d, %d", event, row, col);    
    term.rst();
}
